JsDoc Reference - ColVis#s

Generated by JsDoc Toolkit 2.4.0 on Wed Dec 15 2010 21:56:17 GMT-0000 (GMT)
HTML template: Codeview

# Namespace ColVis#s

Settings object which contains customisable information for ColVis instance
Defined in: ColVis.js.

Namespace Summary
Constructor Attributes | Constructor Name and Description
--- | ---
| ColVis#s

Field Summary
Field Attributes | Field Name and Description
--- | ---
<static> | ColVis#s.activate Mode of activation.
<static> | ColVis#s.aiExclude List of columns (integers) which should be excluded from the list
<static> | ColVis#s.buttonText Text used for the button
<static> | ColVis#s.dt DataTables settings object
<static> | ColVis#s.hidden Flag to say if the collection is hidden

Namespace Detail
ColVis#s
Field Detail
<static> {String} ColVis#s.activate
Mode of activation. Can be 'click' or 'mouseover'

Default Value:
  click

<static> {Array} ColVis#s.aiExclude
List of columns (integers) which should be excluded from the list

Default Value:
  []

<static> {String} ColVis#s.buttonText
Text used for the button

Default Value:
  Show / hide columns

<static> {Object} ColVis#s.dt
DataTables settings object

Default Value:
  null

<static> {boolean} ColVis#s.hidden
Flag to say if the collection is hidden

Default Value:
  true